function [tsMatrix, tsCenters] = buildPatchReferenceMatrix(z, selfSimilarityParams, do_show)
%
% function [tsMatrix, tsCenters] = buildPatchReferenceMatrix(z, selfSimilarityParams, do_show)
%
% tsMatrix    a matrix of overlapping patches of the training set. Each row contains a patch
% tsCenters  a vector of patches centers coordinates
%
% when selfSimilarityParams.do_normalize_patches == 1 
% tsMatrix  becomes a matrix of *zero-mean* overlapping patches of the training set. Each row contains a patch
%
% References
%
% [1]  Cesare Alippi, Giacomo Boracchi and Manuel Roveri,
% "A just-in-time adaptive classification system based on the intersection of confidence intervals rule,"
% Neural Networks, Elsevier vol. 24 (2011), pp. 791-800 doi: 10.1016/j.neunet.2011.05.012
%
%
% preprints available at http://home.deib.polimi.it/boracchi/publications.html
%
%
% Giacomo Boracchi
% Politecnico di Milano
% January 2014
% giacomo.boracchi@polimi.it

if ~exist('do_show', 'var')|| isempty(do_show)
    do_show = 0;
end

signalTS_len = selfSimilarityParams.signalTS_len;
patchSize = selfSimilarityParams.patchSize;
do_normalize_patches = selfSimilarityParams.do_normalize_patches;
 
HPS = floor(patchSize / 2);
% build the training matrixes
tsMatrix = NaN(signalTS_len - patchSize, patchSize);
tsMatrix0 = tsMatrix; % training set for zero-mean patches
tsCenters = NaN(signalTS_len- patchSize, 1); % a vector containing the indexes in the TS of the patch centers
cnt = 1;
for ii = HPS + 1 : signalTS_len - HPS
    tsMatrix(ii - HPS, :) = z(ii - HPS : ii + HPS);
    tsMatrix0(ii - HPS, :) = tsMatrix(ii - HPS, :) - mean(tsMatrix(ii - HPS, :));
    tsCenters(cnt) = ii;
    cnt = cnt + 1;
end

if do_normalize_patches
    tsMatrix = tsMatrix0;
end

if do_show
    disp(['last element of the ts is ', num2str(ii + HPS), ' patch centered in ', num2str(tsCenters(1)), ' - ', num2str(tsCenters(end))])
end

if any(isnan(tsMatrix))
    error('TS Matrix not correctly prepared');
end

