function params = define_Self_Similarity_parameters(period, nPeriodsTS)
%
%
% function params = define_Self_Similarity_parameters(period, nPeriodsTS)
%
% when period is not specified, empty or zero, the serach region for similar patches spans the whole training set.  Then
% then params.fully_non_local  =1 and the training set size becomes nPeriods expressed as a number of samples
% 
%
% 
%
% References
%
% [1]  Cesare Alippi, Giacomo Boracchi and Manuel Roveri,
% "A just-in-time adaptive classification system based on the intersection of confidence intervals rule,"
% Neural Networks, Elsevier vol. 24 (2011), pp. 791-800 doi: 10.1016/j.neunet.2011.05.012
%
%
% preprints available at http://home.deib.polimi.it/boracchi/publications.html
%
%
% Giacomo Boracchi
% Politecnico di Milano
% January 2014
% giacomo.boracchi@polimi.it
%
%
% REVISION HISTORY
% January 2014     First Release
%
%

if ~exist('period', 'var') || isempty(period) || period <= 0 
    params.do_fully_non_local = 1; % when 1 similar patches are searched through all the TS
    period = 0;
else
    params.do_fully_non_local = 0; % when 0 similar patches are searched in a SEARCH_NEIGH of the reference time instant
end

if ~exist('nPeriodsTS', 'var') || isempty(nPeriodsTS) || nPeriodsTS <= 0 
    nPeriodsTS = 400; % when 1 similar patches are searched through all the TS
end

params.nPeriodsTS = nPeriodsTS;
params.patchSize = 11; % assumed to be odd
params.HPS = floor(params.patchSize / 2); % half-patch size
params.do_windowing = 0; % compute weighted distance between patches, using a Gaussian kernel
params.sigmaWindowing = 3;
params.searchNeighSize = 11;
params.do_normalize_patches = 0; % remove mean from patches, not advisable

params.period = period;  % to be used only when do_fully_nonlocal == 0 power-data = 96, bwdn 144

if  params.do_fully_non_local
    params.signalTS_len = nPeriodsTS;
else
    params.signalTS_len = params.nPeriodsTS * params.period;
end