function str = createChangeParamsString(changeParams)
%
% function str = createChangeParamsString(changeParams)
%
% creates a string indicating sort of change and magnitude. 
%
% Giacomo Boracchi
% Politecnico di Milano
% July 2014
% giacomo.boracchi@polimi.it
%
% References
%
% [1] Giacomo Boracchi and Manuel Roveri,
% "Exploiting Self-Similarity for Change Detection"
% in Proceedings of IJCNN 2014, International Joint Conference on Neural Networks
% Beijing, China 5 - 11 July 2014. [Preprint available online at http://home.deib.polimi.it/boracchi/publications.html
%
% [2]  Cesare Alippi, Giacomo Boracchi and Manuel Roveri,
% "A just-in-time adaptive classification system based on the intersection of confidence intervals rule,"
% Neural Networks, Elsevier vol. 24 (2011), pp. 791-800 doi: 10.1016/j.neunet.2011.05.012


    % synthtetically add N - T_star samples after the change
    switch(lower(changeParams.changeType))
        case 'source' % change the source generating data, though the period remains the same
            str= 'source change';
        case {'sourceandrescale', 'source+rescale'} % change the source generating data, the period remains the same and rescale the second source to meet the same mean of the first
         str= 'source and rescale change';
        case 'offset'
            str= ['offset of ', num2str(changeParams.offset)];
        case {'sensordegradation', 'sensor degradation'}
            str= ['sensor degradation parameter ', num2str(changeParams.sensorDegradationStd)];
        case 'gain'
            str= ['gain of ', num2str(changeParams.gain)];
        case {'offset+gain', 'offsetgain', 'gain+offset'}
            str= ['gain of ', num2str(changeParams.gain), ' offset of ', num2str(changeParams.offset)];
        case 'stackat'
             str= ['stackat'];
        otherwise
            str =[changeParams.changeType, ' not recognized'];
    end
end

